.Spam is a list holding information used for
constructing and displaying spam objects..Spamdrop when subsettingimage or display. Larger matrices are represented
as dots only.FALSE or the values themselves (TRUE) when returning the
upper and lower triangular part of a matrix.image or display.FALSE
would solve the system without using the permutation.spam objects. TRUE is safe but only slightly slower.eps, printsize,
imagesize and drop.
bcksl and safemode are rather developing flags.
It is the users responsibility to use a safemode=FALSE. In many
cases, all runs smoothly but there might be instances (especially when
assigning directly to slots) that crash R. The verification is done
with the functions icheck and dcheck.print,
display, image, upper.tri.smat <- diag.spam( 1:8)
smat
.Spam$printsize <- 49
smatRun the code above in your browser using DataLab