Learn R Programming

spam (version 0.15-2)

history: Brief overview of the history

Description

Brief overview of spams history

Usage

spam.history()

Arguments

Details

This list is maintained for releases 0.05 and higher. {0.15: Induced by need to catch up the devel versions of 0.14.} {0.14: Complete rewrite of chol, implementation of update.spam.chol.NgPeyton and related routines. Rewrite of spam.chol.NgPeyton class. Proper spam.options handling. Kronecker product implementation. Rewrite of cbind. Importing and handling of foreign formats. Many internal changes for efficieny increases. Major file renaming. Some backwards compatibility loss.} {0.13: Minor changes to avoid some warning/errors when compiling on different platforms.} {0.12: Many internal changes. Start maintaining a proper CHANGELOG file.} {0.11: Considerable help file improvements. Changes in c/rbind, chol, print/summary methods and other minor improvements, first push to CRAN.} {0.10: Minor bug fixes and help file improvements.} {0.09: Proper NAMESPACE handling.} {0.08: fields uses spam now as a required package. The required linking functions are implemented in fields.} {0.07: Change of slot names.} {0.06: Implements spam and the function linking fields version 3.6. Last stable version before the "merging" with fields. Update to R2.4 and documentation fill-in.} {0.05: Implements spam and the function linking fields version 3.2. It should represent a fair working version, with large gaps in the documentation.}

References

See also a more detailed description at http://www.mines.edu/~rfurrer/software/spam/history.shtml.

See Also

todo.

Examples

Run this code
## A complete history of changes
file.show(system.file("NEWS", package = "spam"))

Run the code above in your browser using DataLab