Rdocumentation
powered by
Learn R Programming
spam (version 1.2-1)
spam-deprecated: Deprecated Objects in Package
spam
Description
The functions or variables listed here are provided for compatibility with older versions of Ronly, and may be defunct as soon as of the next release.
Usage
subset.rows.spam(...)
Arguments
...
some arguments
See Also
Deprecated
,
Defunct